@@ -10,19 +10,19 @@ our $alien_key = 'gtk2_2_8_12_uni_gcc_3_4';
 {
     my $VAR1;
     $Wx::dlls = $VAR1 = {
-          'stc' => 'libwx_gtk2u_stc-2.8.dll.a',
           'aui' => 'libwx_gtk2u_aui-2.8.dll.a',
-          'html' => 'libwx_gtk2u_html-2.8.dll.a',
-          'xrc' => 'libwx_gtk2u_xrc-2.8.dll.a',
-          'qa' => 'libwx_gtk2u_qa-2.8.dll.a',
-          'gl' => 'libwx_gtk2u_gl-2.8.dll.a',
-          'richtext' => 'libwx_gtk2u_richtext-2.8.dll.a',
+          'net' => 'libwx_baseu_net-2.8.dll.a',
           'adv' => 'libwx_gtk2u_adv-2.8.dll.a',
-          'base' => 'libwx_baseu-2.8.dll.a',
-          'gizmos' => 'libwx_gtk2u_gizmos-2.8.dll.a',
-          'xml' => 'libwx_baseu_xml-2.8.dll.a',
           'core' => 'libwx_gtk2u_core-2.8.dll.a',
-          'net' => 'libwx_baseu_net-2.8.dll.a'
+          'xrc' => 'libwx_gtk2u_xrc-2.8.dll.a',
+          'html' => 'libwx_gtk2u_html-2.8.dll.a',
+          'qa' => 'libwx_gtk2u_qa-2.8.dll.a',
+          'stc' => 'libwx_gtk2u_stc-2.8.dll.a',
+          'richtext' => 'libwx_gtk2u_richtext-2.8.dll.a',
+          'xml' => 'libwx_baseu_xml-2.8.dll.a',
+          'gizmos' => 'libwx_gtk2u_gizmos-2.8.dll.a',
+          'base' => 'libwx_baseu-2.8.dll.a',
+          'gl' => 'libwx_gtk2u_gl-2.8.dll.a'
         };
 ;
 }
